==> ember_0.6.2+dfsg.orig.tar.xz: ember-0.6.2/src/components/ogre/OgreResourceProvider.h <==
//
// C++ Interface: OgreResourceProvider
//
// Description:
//
//
// Author: Erik Hjortsberg <erik.hjortsberg@gmail.com>, (C) 2007
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.//
//
#ifndef EMBEROGREOGRERESOURCEPROVIDER_H
#define EMBEROGREOGRERESOURCEPROVIDER_H

#include "framework/IScriptingProvider.h"
#include "components/ogre/EmberOgrePrerequisites.h"
#include <OgreDataStream.h>

namespace Ember {
namespace OgreView {


class OgreResourceWrapper : public IResourceWrapper
{
public:
	OgreResourceWrapper(Ogre::DataStreamPtr dataStream);
	virtual ~OgreResourceWrapper();

	virtual char* getDataPtr();
	virtual bool hasData();
	virtual size_t getSize();
private:
	char* mBuffer;
	size_t mSize;
};


/**
	@author Erik Hjortsberg <erik.hjortsberg@gmail.com>
*/
class OgreResourceProvider : public IResourceProvider
{
public:
    OgreResourceProvider(const std::string& groupName);

    virtual ~OgreResourceProvider();

	virtual ResourceWrapper getResource(const std::string& name);
private:
	std::string mGroupName;

};

}

}

#endif

==> ember_0.7.2+dfsg.orig.tar.xz: ember-0.7.2/src/components/ogre/OgreResourceProvider.h <==
//
// C++ Interface: OgreResourceProvider
//
// Description:
//
//
// Author: Erik Hjortsberg <erik.hjortsberg@gmail.com>, (C) 2007
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.//
//
#ifndef EMBEROGREOGRERESOURCEPROVIDER_H
#define EMBEROGREOGRERESOURCEPROVIDER_H

#include "framework/IResourceProvider.h"
#include "components/ogre/EmberOgrePrerequisites.h"
#include <OgreDataStream.h>

namespace Ember {
namespace OgreView {


class OgreResourceWrapper : public IResourceWrapper
{
public:
	OgreResourceWrapper(Ogre::DataStreamPtr dataStream);
	virtual ~OgreResourceWrapper();

	virtual const char* getDataPtr();
	virtual bool hasData();
	virtual size_t getSize();
private:
	char* mBuffer;
	size_t mSize;
};


/**
	@author Erik Hjortsberg <erik.hjortsberg@gmail.com>
*/
class OgreResourceProvider : public IResourceProvider
{
public:
    OgreResourceProvider(const std::string& groupName);

    virtual ~OgreResourceProvider();

	virtual ResourceWrapper getResource(const std::string& name);
private:
	std::string mGroupName;

};

}

}

#endif
